function [yt,IMS,parms_sim,etaMS_sim] = simulatedata_MS(dd,ar,parms,etaMS,N,T)

%[yt IMS parms_sim] = simulatedata_MS(1,2,[0.5 0.3 0.5 0.01],[0.7 0.3;0.2 0.8],1,70);
%[yt IMS parms_sim] = simulatedata_MS(1,2,[0.5 0.3 0.5 0.01;0.8 0.3 0.6 0.01],[0.7 0.3;0.2 0.8],2,70);
%etaMS=[0.7 0.3;0.2 0.8];
%etaMS(:,:,2)=[0.65 0.35;0.3 0.7];
%etaMS(:,:,3)=[0.8 0.2;0.1 0.9];
%[yt IMS parms_sim etaMS_sim] = simulatedata_MS(1,2,[0.5 0.3 0.5 0.01;0.8 0.3 0.6 0.01],etaMS(:,:,1:2),100,30);

% function to simulate an autoregressive panel 
% y_it = mu_i1 + phi_i*y_it-1 + mu_i2*(I_t^i-1) + e_it   e_it ~ N(0,sigma_i^2)
% dd    number of switching group-specific parameters
% ar    column of parms containing phi_i
% parms Kx.. matrix of parameters [mu_1 phi mu_2 sigma^2], K number of groups to simulate
% etaMS transition probabilities
%       2x2xK for group-specific transition probabilities
%       2x2 for group-independent transition probabilities
% N     cross-section dimension within each group
% T     time dimension

% yt    TxN*K matrix of simulated data
% IMS   KxT matrix of group-specific state-variable

randn('state',0);
rand('state',0);

K=size(parms,1);
nst=size(etaMS,1);

b0=100; %burn-in
T1=T+b0;
yt=zeros(T1,N*K); %dimensions will be reduced at the end
IMS=zeros(K,T1);
parms_sim=zeros(K,size(parms,2));
etaMS_sim=zeros(nst,nst,K);

rd = randn(T1,N*K);

rho=zeros(K,nst);

if size(etaMS,3)==1
    etaMS=etaMS(:,:,ones(K,1));
end

%simulate IMS
for j=1:K
    IMS(j,:) = simulstprior(T1,etaMS(:,:,j),1/nst*(ones(1,nst))')-1;
    [v d] = eig(etaMS(:,:,j));
    rho(j,:)= v(:,end)'./sum(v(:,end)); %compute unconditional state probabilities 
end

%simulate first observation out of the unconditional distribution CHANGE APPROPRIATELY
% E(y_it)= rho_i1 *(mu_i1-mu_i2)/(1-phi_i)+rho_i2 *(mu_i1)/(1-phi_i)
% Var(y_it)= sigma_i^2/(1-phi_i)^2
m=(parms(:,1).*rho(:,2)+(parms(:,1)-parms(:,3)).*rho(:,1))./(1-parms(:,ar));
V= parms(:,end)./((1-parms(:,ar)).^2);

yt(1,:)= kron(m,ones(N,1))' + kron(sqrt(V),ones(N,1))'.*rd(1,:);

c0=kron(parms(:,1),ones(N,1))'; %time-independent mean of y_it 
ct= kron(ones(T1,1),[kron(parms(:,3),ones(N,1))']).*(kron(IMS,ones(N,1))'-1); %time-dependent mean of y_it
phi=kron(parms(:,ar),ones(N,1))';
sig=kron(sqrt(parms(:,end)),ones(N,1))';

for j=2:T1
    yt(j,:) = c0 + ct(j,:) + phi.*yt(j-1,:) + sig.*rd(j,:);
end

yt = yt(end-T+1:end,:);
IMS = IMS(:,end-T+1:end);

%estimate the parameters out of the simulated data
for j=1:K
    X=[ones(N*(T-1),1) reshape(yt(1:end-1,(j-1)*N+[1:N]),N*(T-1),1) kron(ones(N,1),IMS(j,2:end)')-1];
    y=reshape(yt(2:end,(j-1)*N+[1:N]),N*(T-1),1);
    parms_sim(j,1:end-1)= (inv(X'*X)*X'*y)';
    parms_sim(j,end)= sum((y-X*parms_sim(j,1:end-1)').^2)/(N*T-size(parms,2)-1);
    ct = countrns(IMS(j,:)+1,nst);
    etaMS_sim(:,:,j) = ct ./ kron(ones(1,nst),sum(ct,2));
end

